# <img alt="matminer" src="docs_rst/_static/matminer_logo_small.png" width="300">

matminer is a library for performing data mining in the field of materials science.

- **Website (including documentation):** https://hackingmaterials.github.io/matminer/
- **Examples:** https://github.com/hackingmaterials/matminer_examples
- **Help/Support:** https://groups.google.com/forum/#!forum/matminer
- **Source:** https://github.com/hackingmaterials/matminer

If you find matminer useful, please encourage its development by citing the following paper in your research:
```
Ward, L., Dunn, A., Faghaninia, A., Zimmermann, N. E. R., Bajaj, S., Wang, Q.,
Montoya, J. H., Chen, J., Bystrom, K., Dylla, M., Chard, K., Asta, M., Persson,
K., Snyder, G. J., Foster, I., Jain, A., Matminer: An open source toolkit for
materials data mining. Comput. Mater. Sci. 152, 60-69 (2018).
```
